Arc

Struct Arc 

pub struct Arc<T: Float + FloatConst> { /* private fields */ }
An Arc of a Great Circle on a unit sphere.

Implementations

Source

impl<T> Arc<T>
where T: Float + FloatConst + Scalar + ComplexField<RealField = T>, f64: From<T>,

pub const fn new( a: Vector3<T>, pole: Vector3<T>, length: Radians<T>, half_width: Radians<T>, ) -> Self

Construct an Arc

  • a - the start point of the Arc.
  • pole - the right hand pole of the Great Circle of the Arc.
  • length - the length of the Arc.
  • half_width - the half width of the Arc.
pub fn from_lat_lon_azi_length( a: &LatLong<T>, azimuth: Angle<T>, length: Radians<T>, ) -> Self

Construct an Arc

  • a - the start position
  • azimuth - the azimuth at a.
  • length - the length of the Arc.
pub fn between_positions(a: &LatLong<T>, b: &LatLong<T>) -> Self

Construct an Arc from the start and end positions.

Note: if the points are the same or antipodal, the pole will be invalid.

  • a, b - the start and end positions
pub const fn set_half_width(&mut self, half_width: Radians<T>) -> &mut Self

Set the half_width of an Arc.

  • half_width - the half width of the Arc.
pub const fn a(&self) -> Vector3<T>

The start point of the Arc.

pub const fn pole(&self) -> Vector3<T>

The right hand pole of the Great Circle at the start point of the Arc.

pub const fn length(&self) -> Radians<T>

The length of the Arc.

pub const fn half_width(&self) -> Radians<T>

The half width of the Arc.

pub fn azimuth(&self) -> Angle<T>

The azimuth at the start point.

pub fn direction(&self) -> Vector3<T>

The direction vector of the Arc at the start point.

pub fn position(&self, distance: Radians<T>) -> Vector3<T>

A position vector at distance along the Arc.

pub fn b(&self) -> Vector3<T>

The end point of the Arc.

pub fn mid_point(&self) -> Vector3<T>

The mid point of the Arc.

pub fn perp_position( &self, point: &Vector3<T>, distance: Radians<T>, ) -> Vector3<T>

The position of a perpendicular point at distance from the Arc.

  • point a point on the Arc’s great circle.
  • distance the perpendicular distance from the Arc’s great circle.

returns the point at perpendicular distance from point.

pub fn angle_position(&self, angle: Angle<T>) -> Vector3<T>

The position of a point at angle from the Arc start, at Arc length.

  • angle the angle from the Arc start.

returns the point at angle from the Arc start, at Arc length.

pub fn end_arc(&self, at_b: bool) -> Self

The Arc at the end of an Arc, just the point if half_width is zero.

@param at_b if true the Arc at b, else the Arc at a.

@return the end Arc at a or b.

pub fn calculate_atd_and_xtd( &self, point: &Vector3<T>, ) -> (Radians<T>, Radians<T>)

Calculate great-circle along and across track distances of point from the Arc.

  • point - the point.

returns the along and across track distances of the point in Radians.

pub fn shortest_distance(&self, point: &Vector3<T>) -> Radians<T>

Calculate the shortest great-circle distance of a point from the Arc.

  • point - the point.

returns the shortest distance of a point from the Arc in Radians.