pub struct LatLong<T: Float> { /* private fields */ }Expand description
A position as a latitude and longitude pair of Degrees.
Implementations
Sourceimpl<T: Float> LatLong<T>
impl<T: Float> LatLong<T>
pub const fn new(lat: Degrees<T>, lon: Degrees<T>) -> Self
pub const fn lat(&self) -> Degrees<T>
pub const fn lon(&self) -> Degrees<T>
Sourcepub fn is_south_of(&self, a: &Self) -> bool
pub fn is_south_of(&self, a: &Self) -> bool
Determine whether the LatLong is South of a.
It compares the latitude of the two points.
a- the otherLatLong.
returns true if South of a, false otherwise.
Sourcepub fn is_west_of(&self, a: &Self) -> bool
pub fn is_west_of(&self, a: &Self) -> bool
Determine whether the LatLong is West of LatLong a.
It compares the longitude difference of the two points.
a,b- the points.
returns true if a is West of b, false otherwise.