pub fn calculate_direction<T: Float>(
lat: Angle<T>,
lon: Angle<T>,
azi: Angle<T>,
) -> Vector3<T>Expand description
Calculate the direction vector along a Great Circle from an initial position and an azimuth.
See: Panou and Korakitis equations: 30, 31, & 32a https://arxiv.org/abs/1811.03513
lat- start point Latitude.lon- start point Longitude.azi- start point azimuth.
returns the direction vector at the point on the great circle.