direction

Function direction 

pub fn direction<T>(a: &Vector3<T>, pole: &Vector3<T>) -> Vector3<T>
where T: Float + Scalar + ComplexField<RealField = T>,
Calculate the direction vector of a Great Circle arc.

  • a - the start point.
  • pole - the pole of a Great Circle.

returns the direction vector at the point on the great circle.