calculate_intersection

Function calculate_intersection 

pub fn calculate_intersection<T>(
    pole_0: &Vector3<T>,
    pole_1: &Vector3<T>,
    min_sq_value: T,
) -> Option<Vector3<T>>
where T: Float + Scalar + ComplexField<RealField = T>,
Calculate an intersection point between the poles of two Great Circles. See: http://www.movable-type.co.uk/scripts/latlong-vectors.html#intersection

  • pole_0, pole_1 the poles.
  • min_sq_value the minimum square of a vector length to normalize.

return an intersection point or None if the poles represent coincident Great Circles.