closest_intersection_point

Function closest_intersection_point 

pub fn closest_intersection_point<T>(
    point: &Vector3<T>,
    centroid: &Vector3<T>,
) -> Vector3<T>
where T: Float + Scalar + ComplexField<RealField = T>,
Return the closer intersection point to the centroid of the Arcs.

  • point a great-circle intersection point.
  • centroid the centroid of the Arcs mid points.

returns the antipodal point if it is closer to the centroid, otherwise returns the point.