pub fn calculate_pole<T: Float>(
lat: Angle<T>,
lon: Angle<T>,
azi: Angle<T>,
) -> Vector3<T>Expand description
Calculate the right hand pole vector of a Great Circle from an initial position and an azimuth.
See: http://www.movable-type.co.uk/scripts/latlong-vectors.html#distance
lat- start point Latitude.lon- start point Longitude.azi- start point azimuth.
returns the right hand pole vector of the great circle.