pub fn delta_longitude<T>(a: &Vector3<T>, b: &Vector3<T>) -> Angle<T>Expand description
Calculate the relative longitude of point a from point b.
a,b- the points.
returns the relative longitude of point a from point b, negative if a is West of b, positive otherwise.