pub fn is_right_of(pole: &Vector3d, point: &Vector3d) -> boolExpand description
Determine whether point is right of a Great Circle pole.
It compares the dot product of the pole and point.
pole- the Great Circle pole.point- the point.
returns true if the point is right of the pole, false if on or to the left of the Great Circle.