is_right_of

Function is_right_of 

pub fn is_right_of<T>(pole: &Vector3<T>, point: &Vector3<T>) -> bool
where T: Float + Scalar + ComplexField<RealField = T>,
Determine whether point is right of a Great Circle pole.

It compares the dot product of the pole and point.

  • pole - the Great Circle pole.
  • point - the point.

returns true if the point is right of the pole, false if on or to the left of the Great Circle.