pub fn normalise<T>(a: &Vector3<T>, min_sq_value: T) -> Option<Vector3<T>>Expand description
Normalize a vector to lie on the surface of the unit sphere.
Note: this function returns an Option so uses the British spelling of
normalise to differentiate it from the standard normalize function.
atheVector3min_sq_valuethe minimum square of a vector length to normalize.
return the nomalized point or None if the vector is too small to normalize.