pub fn position<T>(
a: &Vector3<T>,
dir: &Vector3<T>,
distance: Angle<T>,
) -> Vector3<T>Expand description
Calculate the position of a point along a Great Circle arc.
a- the start point.dir- the direction vector of a Great Circle at a.distance- the a Great Circle as an Angle.
returns the position vector at the point on the great circle.