pub fn rotate<T>(
dir: &Vector3<T>,
pole: &Vector3<T>,
angle: Angle<T>,
) -> Vector3<T>Expand description
Calculate the direction vector of a Great Circle rotated by angle.
dir- the direction vector of a Great Circle arc.pole- the pole of a Great Circle.angle- the angle to rotate the direction vector by.
returns the direction vector at the point on the great circle rotated by angle.