rotate_position

Function rotate_position 

pub fn rotate_position<T>(
    a: &Vector3<T>,
    pole: &Vector3<T>,
    angle: Angle<T>,
    radius: Angle<T>,
) -> Vector3<T>
where T: Float + Scalar + ComplexField<RealField = T>,
Calculate the position of a point rotated by angle at radius.

  • a - the start point.
  • pole - the pole of a Great Circle.
  • angle - the angle to rotate the direction vector by.
  • radius - the radius from the start point.

returns the position vector at angle and radius from the start point.