pub fn sin_atd<T>(
a: &Vector3<T>,
pole: &Vector3<T>,
point: &Vector3<T>,
) -> UnitNegRange<T>Expand description
The sine of the along track distance of a point along a Great Circle arc.
It is the triple product of the pole, a and the point: (pole X a) . point = pole . (a X point)
a- the start point of the Great Circle arc.pole- the pole of the Great Circle arc.point- the point.
returns the sine of the along track distance of point relative to the start of a great circle arc.