pub fn sq_distance<T>(a: &Vector3<T>, b: &Vector3<T>) -> TExpand description
Calculate the square of the Euclidean distance between two points.
Note: points do NOT need to be valid Points. @post for unit vectors: result <= 4
a,bthe points.
returns the square of the Euclidean distance between the points.