pub fn calculate_intersection<T>(
pole_0: &Vector3<T>,
pole_1: &Vector3<T>,
min_sq_value: T,
) -> Option<Vector3<T>>Expand description
Calculate an intersection point between the poles of two Great Circles. See: http://www.movable-type.co.uk/scripts/latlong-vectors.html#intersection
pole_0,pole_1the poles.min_sq_valuethe minimum square of a vector length to normalize.
return an intersection point or None if the poles represent coincident Great Circles.