pub fn closest_intersection_point<T>(
point: &Vector3<T>,
centroid: &Vector3<T>,
) -> Vector3<T>Expand description
Return the closer intersection point to the centroid of the Arcs.
pointa great-circle intersection point.centroidthe centroid of theArcs mid points.
returns the antipodal point if it is closer to the centroid,
otherwise returns the point.